@@ -54,6 +54,8 @@ if __name__ == '__main__':
         mydll = ctypes.windll.LoadLibrary(sys.prefix + '/pcc.dll')
     if cur_paltform == 'macOS':
         mydll = CDLL(sys.prefix + '/pcc.dylib')
+    if cur_paltform == 'Linux':
+        mydll = CDLL(sys.prefix + '/pcc.so')
     #mydll.Pearson_Correlation.argtypes = [POINTER(c_double), POINTER(c_double), c_long, POINTER(c_double)]
     # newdata = np.arange(0,20000,2)
     # refdata = np.arange(10000,30000,2)
